@@ -40,12 +40,12 @@
 #*/###########################################################################
 setConstructorS3("AromaGenomeTextFile", function(...) {
   extend(TabularTextFile(...), c("AromaGenomeTextFile",
-                                              uses("FileCacheKeyInterface")));
+                                              uses("FileCacheKeyInterface")))
 })
 
 
 setMethodS3("readDataFrame", "AromaGenomeTextFile", function(this, ..., colClasses=c("*"="NULL", chromosome="character", nbrOfBases="integer", nbrOfGenes="integer")) {
-  NextMethod("readDataFrame", colClasses=colClasses);
+  NextMethod("readDataFrame", colClasses=colClasses)
 })
 
 
@@ -55,29 +55,29 @@ setMethodS3("readDataFrame", "AromaGenomeTextFile", function(this, ..., colClass
 ##   # Validate arguments
 ##   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ##   # Argument 'verbose':
-##   verbose <- Arguments$getVerbose(verbose);
+##   verbose <- Arguments$getVerbose(verbose)
 ##   if (verbose) {
-##     pushState(verbose);
-##     on.exit(popState(verbose));
+##     pushState(verbose)
+##     on.exit(popState(verbose))
 ##   }
 ##
 ##
-##   verbose && enter(verbose, "Reading genome chromosome annotation file");
+##   verbose && enter(verbose, "Reading genome chromosome annotation file")
 ##
-##   data <- readDataFrame(this, ..., verbose=less(verbose, 10));
+##   data <- readDataFrame(this, ..., verbose=less(verbose, 10))
 ##
-##   verbose && enter(verbose, "Translating chromosome names");
-##   chromosomes <- row.names(data);
-##   map <- c("X"=23, "Y"=24, "Z"=25);  # AD HOC; only for the human genome
+##   verbose && enter(verbose, "Translating chromosome names")
+##   chromosomes <- row.names(data)
+##   map <- c("X"=23, "Y"=24, "Z"=25) # AD HOC: only for the human genome
 ##   for (kk in seq_along(map)) {
-##     chromosomes <- gsub(names(map)[kk], map[kk], chromosomes, fixed=TRUE);
+##     chromosomes <- gsub(names(map)[kk], map[kk], chromosomes, fixed=TRUE)
 ##   }
-##   row.names(data) <- chromosomes;
-##   verbose && exit(verbose);
+##   row.names(data) <- chromosomes
+##   verbose && exit(verbose)
 ##
-##   verbose && exit(verbose);
+##   verbose && exit(verbose)
 ##
-##   data;
+##   data
 ## })
 
 
@@ -87,48 +87,48 @@ setMethodS3("findByGenome", "AromaGenomeTextFile", function(static, genome, tags
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'genome':
-  genome <- Arguments$getCharacter(genome);
+  genome <- Arguments$getCharacter(genome)
 
   # Argument 'tags':
-  tags <- Arguments$getTags(tags, collapse=",");
+  tags <- Arguments$getTags(tags, collapse=",")
 
   # Argument 'pattern':
   if (!is.null(pattern)) {
-    pattern <- Arguments$getRegularExpression(pattern);
+    pattern <- Arguments$getRegularExpression(pattern)
   }
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
-  verbose && enter(verbose, "Locating genome annotation file");
+  verbose && enter(verbose, "Locating genome annotation file")
 
-  fullname <- paste(c(genome, tags), collapse=",");
+  fullname <- paste(c(genome, tags), collapse=",")
 
-  verbose && cat(verbose, "Genome name: ", genome);
-  verbose && cat(verbose, "Genome tags: ", tags);
-  verbose && cat(verbose, "Genome fullname: ", fullname);
-  verbose && cat(verbose, "Pattern (fmtstr): ", pattern);
-  patternT <- sprintf(pattern, fullname);
-  verbose && cat(verbose, "Pattern (updated): ", patternT);
-  verbose && cat(verbose, "Paths:");
-  verbose && print(verbose, paths);
+  verbose && cat(verbose, "Genome name: ", genome)
+  verbose && cat(verbose, "Genome tags: ", tags)
+  verbose && cat(verbose, "Genome fullname: ", fullname)
+  verbose && cat(verbose, "Pattern (fmtstr): ", pattern)
+  patternT <- sprintf(pattern, fullname)
+  verbose && cat(verbose, "Pattern (updated): ", patternT)
+  verbose && cat(verbose, "Paths:")
+  verbose && print(verbose, paths)
 
   pathname <- findAnnotationData(name=fullname, set="genomes",
                                  pattern=patternT, paths=paths, ...,
-                                      verbose=less(verbose, 10));
+                                      verbose=less(verbose, 10))
 
   if (!is.null(pathname)) {
-    verbose && cat(verbose, "Found file: ", pathname);
+    verbose && cat(verbose, "Found file: ", pathname)
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  pathname;
+  pathname
 }, static=TRUE, protected=TRUE)
 
 
@@ -137,53 +137,34 @@ setMethodS3("byGenome", "AromaGenomeTextFile", function(static, genome, ..., mus
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'mustExist':
-  mustExist <- Arguments$getLogical(mustExist);
+  mustExist <- Arguments$getLogical(mustExist)
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
-  verbose && enter(verbose, "Locating genome annotation file");
+  verbose && enter(verbose, "Locating genome annotation file")
 
   # Locate genome file
-  pathname <- findByGenome(static, genome=genome, ..., verbose=verbose);
+  pathname <- findByGenome(static, genome=genome, ..., verbose=verbose)
 
   if (is.null(pathname)) {
-    res <- NULL;
+    res <- NULL
   } else {
-    res <- newInstance(static, pathname);
+    res <- newInstance(static, pathname)
   }
 
   if (mustExist && is.null(res)) {
-    msg <- sprintf("Failed to locate a genome annotation data file for genome '%s'.", genome);
-    verbose && cat(verbose, msg);
-    throw(msg);
+    msg <- sprintf("Failed to locate a genome annotation data file for genome '%s'.", genome)
+    verbose && cat(verbose, msg)
+    throw(msg)
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  res;
+  res
 }, static=TRUE)
-
-
-############################################################################
-# HISTORY:
-# 2014-02-03
-# o BUG FIX: readDataFrame() for AromaGenomeTextFile explicitly passed
-#   arguments '...' to NextMethod(), which would cause them to be
-#   duplicated in certain cases.
-# 2011-03-03
-# o Replaced argument 'onMissing' of byGenome() with 'mustExist'.
-# o Now findByGenome() for AromaGenomeTextFile follows the new aroma
-#   search conventions.
-# o Updated the default filename patterns used by findByGenome() for
-#   AromaGenomeTextFile to "^%s,chromosomes(|,.*)*[.]txt$".  Before
-#   additional tags were needed.
-# 2010-08-22
-# o Added Rdoc comments and an example.
-# o Created.
-############################################################################
