@@ -26,24 +26,14 @@ setConstructorS3("RawSequenceReads", function(x=NULL, y=rep(1L, length(x)), ...)
 })
 
 setMethodS3("nbrOfReads", "RawSequenceReads", function(this, ...) {
-  nbrOfLoci(this, ...);
+  nbrOfLoci(this, ...)
 })
 
 setMethodS3("binnedSums", "RawSequenceReads", function(this, ...) {
-  binnedSmoothing(this, ..., FUN=sum);
+  binnedSmoothing(this, ..., FUN=sum)
 })
 
 
 setMethodS3("plot", "RawSequenceReads", function(x, ..., ylim=c(0,10), ylab="Reads") {
-  NextMethod("plot", ylim=ylim, ylab=ylab);
+  NextMethod("plot", ylim=ylim, ylab=ylab)
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2010-09-11
-# o Added an explicit 'ylim' argument to plot() for RawSequenceReads. 
-# 2009-07-02
-# o Created from RawCopyNumbers.R.
-############################################################################
